﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Resources.Appearance;
using System.Diagnostics;
using Infragistics.UltraChart.Core.Primitives;
using Infragistics.UltraChart.Core;

namespace WC_DropLines
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            ultraChart1.ChartType = ChartType.ScatterChart;
            ultraChart1.Series.Add(GetScatterSeries());
            ultraChart1.DataBind();

            ultraChart1.ScatterChart.ConnectWithLines = true;
            ultraChart1.ScatterChart.Icon = SymbolIcon.Diamond;

            ultraChart1.Axis.Y.RangeType = AxisRangeType.Custom;
            ultraChart1.Axis.Y.RangeMin = 0;
            ultraChart1.Axis.Y.RangeMax = 20;

            ultraChart1.Axis.X.RangeType = AxisRangeType.Custom;
            ultraChart1.Axis.X.RangeMin = 4;
            ultraChart1.Axis.X.RangeMax = 15;
        }

        private XYSeries GetScatterSeries()
        {
            XYSeries series = new XYSeries();
            series.Points.Add(new XYDataPoint(5, 12, "Point A", false));
            series.Points.Add(new XYDataPoint(8, 10, "Point B", false));
            series.Points.Add(new XYDataPoint(9, 14, "Point C", false));
            series.Points.Add(new XYDataPoint(10.5, 12, "Point D", false));
            series.Points.Add(new XYDataPoint(11, 16, "Point E", false));
            series.Points.Add(new XYDataPoint(14, 13, "Point F", false));
            return series;
        }

        private NumericSeries GetSplineSeries()
        {
            NumericSeries series = new NumericSeries();

            series.Points.Add(new NumericDataPoint(5, "Point A", false));
            series.Points.Add(new NumericDataPoint(8, "Point B", false));
            series.Points.Add(new NumericDataPoint(9, "Point C", false));
            series.Points.Add(new NumericDataPoint(10.5, "Point D", false));
            series.Points.Add(new NumericDataPoint(11, "Point E", false));
            series.Points.Add(new NumericDataPoint(14, "Point F", false));

            return series;
        }

        private void ultraChart1_FillSceneGraph(object sender, Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e)
        {
            switch (e.ChartCore.ChartType)
            {
                case ChartType.ScatterChart:
                    DrawDropLineForScatterChart(e);
                    break;
                case ChartType.SplineChart:
                    DrawDropLineForSplineChart(e);
                    break;
                default:
                    break;
            }
        }

        private void DrawDropLineForSplineChart(Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e)
        {
            var polyLines = e.SceneGraph.OfType<Polyline>().ToList();
            foreach (var polyLine in polyLines)
            {
                foreach (var point in polyLine.points)
                {
                    var yAxis = e.Grid["Y"] as IAdvanceAxis;
                    var xAxis = e.Grid["X"] as IAdvanceAxis;

                    var coordY = yAxis.Map(point.Value);
                    var coordX = xAxis.Map(point.Column);
                    var xAxisYCoord = yAxis.MapMinimum;

                    DrawDropLine(e, coordY, coordX, xAxisYCoord);
                }
            }
        }
        private void DrawDropLineForScatterChart(Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e)
        {
            var pointSets = e.SceneGraph.OfType<PointSet>().ToList();
            foreach (var pointSet in pointSets)
            {
                foreach (var point in pointSet.points)
                {
                    var yAxis = e.Grid["Y"] as IAdvanceAxis;
                    var xAxis = e.Grid["X"] as IAdvanceAxis;

                    var values = point.Value as object[];
                    var valueX = values[0];
                    var valueY = values[1];

                    var coordY = yAxis.Map(valueY);
                    var coordX = xAxis.Map(valueX);
                    var xAxisYCoord = yAxis.MapMinimum;

                    DrawDropLine(e, coordY, coordX, xAxisYCoord);
                }
            }
        }

        private void DrawDropLine(Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e, double coordY, double coordX, double xAxisYCoord)
        {
            Line dropLine = new Line(new Point((int)coordX, (int)coordY), new Point((int)coordX, (int)xAxisYCoord));
            dropLine.PE.Stroke = Color.Red;
            dropLine.PE.StrokeWidth = 2;
            dropLine.lineStyle.DrawStyle = LineDrawStyle.Dash;
            e.SceneGraph.Add(dropLine);
        }

        private void ultraOptionSet1_ValueChanged(object sender, EventArgs e)
        {
            switch (ultraOptionSet1.Value.ToString())
            {
                case "Scatter Chart":
                    ultraChart1.Series.Clear();
                    ultraChart1.ChartType = ChartType.ScatterChart;
                    ultraChart1.Series.Add(GetScatterSeries());
                    ultraChart1.DataBind();
                    ultraChart1.Axis.X.RangeMin = 4;
                    ultraChart1.Axis.X.RangeMax = 15;
                    break;
                case "Spline Chart":
                    ultraChart1.Series.Clear();
                    ultraChart1.ChartType = ChartType.SplineChart;
                    ultraChart1.Series.Add(GetSplineSeries());
                    ultraChart1.DataBind();
                    ultraChart1.Axis.X.RangeMin = 0;
                    ultraChart1.Axis.X.RangeMax = 5;
                    break;
                default:
                    break;
            }

        }
    }
}
